==> visual-third-party-1.1.3-sources.jar: com/tenqube/visual_third/parser/catcher/MMSCatcher.java <==
package com.tenqube.visual_third.parser.catcher;

import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.os.Handler;
import android.text.TextUtils;

import com.tenqube.visual_third.manager.PrefManager;

public class MMSCatcher extends BroadcastReceiver {

    protected static final String TAG = MMSCatcher.class.getSimpleName();
    public static final String MMS_ACTION = "android.provider.Telephony.WAP_PUSH_RECEIVED";

    public MMSHelper mmsHelper;

    public MMSCatcher() {
        super();
    }

    @Override
    public void onReceive(final Context context, Intent intent) {
        try {

            if(intent != null) {

                if(TextUtils.isEmpty(PrefManager.getInstance(context).loadStringValue(PrefManager.UID, "")))
                    return;

                if(mmsHelper == null) mmsHelper = new MMSHelper(context);

                String action = intent.getAction();

                if(action != null) {
                    if (MMS_ACTION.equals(action)) {

                        Runnable runn = new Runnable() {
                            @Override
                            public void run() {

                                Intent startIntent = new Intent(context, SmsMmsService.class);
                                startIntent.putExtra(SmsMmsService.ARG_SMS, mmsHelper.getMMS());
                                context.startService(startIntent);

                            }
                        };
                        Handler handler = new Handler();
                        handler.postDelayed(runn, 4000); // 시간이 너무 짧으면 못 가져오는게 있더라
                    }
                }
            }
        } catch (Exception e) {
            e.printStackTrace();
        }

    }


}

==> visual-third-party-1.1.5-sources.jar: com/tenqube/visual_third/parser/catcher/MMSCatcher.java <==
package com.tenqube.visual_third.parser.catcher;

import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.os.Handler;

import static com.tenqube.visual_third.util.Utils.isSDKDisEnabled;

public class MMSCatcher extends BroadcastReceiver {

    protected static final String TAG = MMSCatcher.class.getSimpleName();
    public static final String MMS_ACTION = "android.provider.Telephony.WAP_PUSH_RECEIVED";

    public MMSHelper mmsHelper;

    public MMSCatcher() {
        super();
    }

    @Override
    public void onReceive(final Context context, Intent intent) {
        try {

            if(intent != null) {

                if(!isSDKDisEnabled(context))
                    return;

                if(mmsHelper == null) mmsHelper = new MMSHelper(context);

                String action = intent.getAction();

                if(action != null) {
                    if (MMS_ACTION.equals(action)) {

                        Runnable runn = new Runnable() {
                            @Override
                            public void run() {

                                Intent startIntent = new Intent(context, SmsMmsService.class);
                                startIntent.putExtra(SmsMmsService.ARG_SMS, mmsHelper.getMMS());
                                context.startService(startIntent);

                            }
                        };
                        Handler handler = new Handler();
                        handler.postDelayed(runn, 4000); // 시간이 너무 짧으면 못 가져오는게 있더라
                    }
                }
            }
        } catch (Exception e) {
            e.printStackTrace();
        }

    }


}
